<?php

namespace App\Console\Commands;
use App\Model\ServiceReminderModel;
use App\Model\User;
use App\Model\VehicleModel;
use App\Notifications\RenewDriverLicence;
use App\Notifications\RenewInsurance;
use App\Notifications\RenewRegistration;
use App\Notifications\RenewVehicleLicence;
use App\Notifications\ServiceReminderNotification;
use Illuminate\Console\Command;

class NotificationsCommand extends Command {

	protected $signature = 'notification:generate';

	protected $description = 'Generate notifications';

	public function __construct() {
		parent::__construct();
	}

	public function handle() {
		$this->service_reminder();
		$this->driver_notify();
		$this->vehicle_notify();
		$this->insurance_notify();
	}

	private function driver_notify() {
		$users = User::where('user_type', 'S')->where('deleted_at', null)->get();
		$d = User::where('user_type', 'D')->where('deleted_at', null)->get();

		foreach ($d as $data) {

			$driver_id = $data->id;
			$lic_date = $data->getMeta('exp_date');
			$msg = $data->getMeta('exp_date');
			$to = \Carbon\Carbon::now();
			$from = \Carbon\Carbon::createFromFormat('Y-m-d', $lic_date);
			$diff_in_days = $to->diffInDays($from);
			if ($diff_in_days <= 20) {
				foreach ($users as $user) {
					$user->notify(new RenewDriverLicence($msg, $driver_id, $lic_date));
				}
			}

		}
	}
	private function vehicle_notify() {
		$users = User::where('user_type', 'S')->where('deleted_at', null)->get();

		$d = VehicleModel::get();
		foreach ($d as $data) {

			$vehicle_id = $data->id;
			$reg_date = $data->reg_exp_date;
			$msg = $data->reg_exp_date;
			$to = \Carbon\Carbon::now();
			$from = \Carbon\Carbon::createFromFormat('Y-m-d', $reg_date);
			$diff_in_days = $to->diffInDays($from);
			if ($diff_in_days <= 20) {
				foreach ($users as $user) {

					$user->notify(new RenewRegistration($msg, $vehicle_id, $reg_date));
				}
			}

		}

		foreach ($d as $data) {

			$vehicle_id = $data->id;
			$lic_date = $data->lic_exp_date;
			$msg = $data->lic_exp_date;
			$to = \Carbon\Carbon::now();
			$from = \Carbon\Carbon::createFromFormat('Y-m-d', $lic_date);
			$diff_in_days = $to->diffInDays($from);
			if ($diff_in_days <= 20) {
				foreach ($users as $user) {

					$user->notify(new RenewVehicleLicence($msg, $vehicle_id, $lic_date));
				}
			}

		}

	}

	private function insurance_notify() {
		$users = User::where('user_type', 'S')->where('deleted_at', null)->get();

		$v = VehicleModel::get();
		foreach ($v as $vehicle) {

			$ins_date = $vehicle->getMeta('ins_exp_date');

			$to = \Carbon\Carbon::now();
			$from = \Carbon\Carbon::createFromFormat('Y-m-d', $ins_date);
			$diff_in_days = $to->diffInDays($from);
			if ($diff_in_days <= 20) {
				foreach ($users as $user) {
					$user->notify(new RenewInsurance($ins_date, $vehicle->id, $ins_date));
				}
			}
		}

	}

	private function service_reminder() {
		$users = User::where('user_type', 'S')->where('deleted_at', null)->get();
		$d = ServiceReminderModel::get();
		foreach ($d as $data) {
			$interval = substr($data->services->overdue_unit, 0, -3);
			$int = $data->services->overdue_time . $interval;
			$date = date('Y-m-d', strtotime($int, strtotime(date('Y-m-d'))));

			$to = \Carbon\Carbon::now();
			$from = \Carbon\Carbon::createFromFormat('Y-m-d', $date);
			$diff_in_days = $to->diffInDays($from);

			$duesoon = substr($data->services->duesoon_unit, 0, -3);
			$int1 = $data->services->duesoon_time . $duesoon;
			$date1 = date('Y-m-d', strtotime($int1, strtotime(date('Y-m-d'))));

			$from1 = \Carbon\Carbon::createFromFormat('Y-m-d', $date1);
			$condition = $to->diffInDays($from1);
			if ($data->services->duesoon_time = null) {
				$condition = 20;
			}
			if ($diff_in_days <= $condition) {
				foreach ($users as $user) {
					$user->notify(new ServiceReminderNotification($data->services->description, $data->id, $date));
				}
			}

		}
	}

}
