<?php

namespace App\Http\Controllers;
use App\Http\Requests\DriverRequest;
use App\Model\Bookings;
use App\Model\ExpCats;
use App\Model\IncCats;
use App\Model\User;
use App\Model\VehicleModel;
use App\Rules\UniqueContractNumber;
use App\Rules\UniqueEId;
use App\Rules\UniqueLicenceNumber;
use Auth;
use DB;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Input;
use Redirect;

class DriversController extends Controller {
	public function index() {
		$index['data'] = User::whereUser_type("D")->get();
		return view("drivers.index", $index);
	}

	public function destroy(Request $request) {
		User::find($request->get('id'))->user_data()->delete();
		User::find($request->get('id'))->delete();

		return redirect()->route('drivers.index');
	}

	public function create() {
		return view("drivers.create");
	}

	public function edit(User $driver) {
		if ($driver->user_type != "D") {
			return redirect("drivers");
		}
		return view("drivers.edit", compact("driver"));
	}

	private function upload_file($file, $field, $id) {
		$destinationPath = './uploads'; // upload path
		$extension = $file->getClientOriginalExtension();

		$fileName1 = Str::uuid() . '.' . $extension;

		$file->move($destinationPath, $fileName1);
		$user = User::find($id);
		$user->setMeta([$field => $fileName1]);
		$user->save();

	}

	public function update(DriverRequest $request) {
		$id = $request->get('id');
		$user = User::find($id);
		if (Input::hasFile('driver_image') && Input::file('driver_image')->isValid()) {
			$this->upload_file(Input::file('driver_image'), "driver_image", $id);
		}

		if (Input::hasFile('license_image') && Input::file('license_image')->isValid()) {
			$this->upload_file(Input::file('license_image'), "license_image", $id);
			$user->id_proof_type = "License";
			$user->save();
		}
		if (Input::hasFile('documents')) {
			$this->upload_file(Input::file('documents'), "documents", $id);

		}
		// dd($request->all());

		$user->name = $request->get("first_name") . " " . $request->get("last_name");
		$user->email = $request->get('email');
		$user->save();
		// $user->driver_image = $request->get('driver_image');
		$form_data = $request->all();
		unset($form_data['driver_image']);
		unset($form_data['documents']);
		unset($form_data['license_image']);

		$user->setMeta($form_data);
		$user->save();

		return Redirect::route("drivers.index");
	}

	public function store(Request $request) {

		$request->validate([
			'emp_id' => ['required', new UniqueEId],
			'license_number' => ['required', new UniqueLicenceNumber],
			'contract_number' => ['required', new UniqueContractNumber],
			'first_name' => 'required',
			'last_name' => 'required',
			'address' => 'required',
			'phone' => 'required|numeric',
			'email' => 'required|email|unique:users,email,' . \Request::get("id"),
			'exp_date' => 'required|date|date_format:Y-m-d|after:tomorrow',
			'start_date' => 'date|date_format:Y-m-d',
		]);

		$id = User::create([
			"name" => $request->get("first_name") . " " . $request->get("last_name"),
			"email" => $request->get("email"),
			"password" => bcrypt($request->get("password")),
			"user_type" => "D",
			'api_token' => str_random(60),
		])->id;
		$user = User::find($id);
		if (Input::hasFile('driver_image') && Input::file('driver_image')->isValid()) {

			$this->upload_file(Input::file('driver_image'), "driver_image", $id);
		}

		if (Input::hasFile('license_image') && Input::file('license_image')->isValid()) {
			$this->upload_file(Input::file('license_image'), "license_image", $id);
			$user->id_proof_type = "License";
			$user->save();
		}
		if (Input::hasFile('documents')) {
			$this->upload_file(Input::file('documents'), "documents", $id);

		}

		$form_data = $request->all();
		unset($form_data['driver_image']);
		unset($form_data['documents']);
		unset($form_data['license_image']);
		$user->setMeta($form_data);
		$user->save();
		return Redirect::route("drivers.index");

	}

	public function enable($id) {
		// $driver = UserMeta::whereUser_id($id)->first();
		$driver = User::find($id);
		$driver->is_active = 1;
		$driver->save();
		return Redirect::route("drivers.index");

	}

	public function disable($id) {
		// $driver = UserMeta::whereUser_id($id)->first();
		$driver = User::find($id);
		$driver->is_active = 0;
		$driver->save();
		return Redirect::route("drivers.index");

	}

	public function my_bookings() {
		$data['data'] = Bookings::orderBy('id', 'desc')->whereDriver_id(Auth::user()->id)->get();
		// dd($data['data']);
		return view('drivers.my_bookings', $data);
	}

	public function yearly() {
		$d_id = Auth::user()->id;
		$bookings = Bookings::where('driver_id', $d_id)->get();
		$v_id = array('0');
		foreach ($bookings as $key) {
			if ($key->vehicle_id != null) {
				$v_id[] = $key->vehicle_id;
			}

		}

		$years = DB::select(DB::raw("select distinct year(date) as years from income  union select distinct year(date) as years from expense order by years desc"));
		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {

			$y[] = date('Y');

		}
		$data['vehicles'] = VehicleModel::whereIn('id', $v_id)->get();

		$data['year_select'] = date("Y");

		$data['vehicle_select'] = null;
		$data['years'] = $y;
		$in = join(",", $v_id);
		$data['income'] = DB::select(DB::raw("select sum(amount) as income from income where deleted_at is null and year(date)=" . date("Y") . " and vehicle_id in(" . $in . ")"));
		$data['expenses'] = DB::select(DB::raw("select sum(amount) as expense from expense where  deleted_at is null and year(date)=" . date("Y") . " and vehicle_id in(" . $in . ")"));
		$data['expense_by_cat'] = DB::select(DB::raw("select expense_type,sum(amount) as expense from expense where deleted_at is null and year(date)=" . date("Y") . "  and vehicle_id in(" . $in . ") group by expense_type"));

		$data['income_by_cat'] = DB::select(DB::raw("select income_cat,sum(amount) as amount from income where deleted_at is null and year(date)=" . date("Y") . " and vehicle_id in(" . $in . ") group by income_cat"));

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		$hh = IncCats::get();

		foreach ($hh as $k) {
			$i[$k->id] = $k->name;

		}
		$data['expense_cats'] = $b;
		$data['income_cats'] = $i;
		$data['result'] = "";
		$data['yearly_income'] = $this->yearly_income();
		$data['yearly_expense'] = $this->yearly_expense();
		return view('drivers.yearly', $data);

	}

	public function yearly_post(Request $request) {
		$d_id = Auth::user()->id;
		$bookings = Bookings::where('driver_id', $d_id)->get();
		foreach ($bookings as $key) {
			$v_id[] = $key->vehicle_id;
		}
		$years = DB::select(DB::raw("select distinct year(date) as years from income  union select distinct year(date) as years from expense order by years desc"));
		$y = array();
		$b = array();
		$i = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		if ($years == null) {
			$y = ['2017', '2016'];
		}
		$data['vehicles'] = VehicleModel::whereIn('id', $v_id)->get();
		$data['year_select'] = $request->get("year");
		$data['vehicle_select'] = $request->get("vehicle_id");
		$data['yearly_income'] = $this->yearly_income();
		$data['yearly_expense'] = $this->yearly_expense();
		$vk = "";
		if ($data['vehicle_select'] != "") {
			$vk = " and vehicle_id=" . $data['vehicle_select'];
		}
		$data['income'] = DB::select(DB::raw("select sum(amount) as income from income where deleted_at is null and year(date)=" . $data['year_select'] . $vk));
		$data['expenses'] = DB::select(DB::raw("select sum(amount) as expense from expense where deleted_at is null and year(date)=" . $data['year_select'] . $vk));
		$data['expense_by_cat'] = DB::select(DB::raw("select expense_type,sum(amount) as expense from expense where deleted_at is null and year(date)=" . $data['year_select'] . "$vk group by expense_type"));

		$data['income_by_cat'] = DB::select(DB::raw("select income_cat,sum(amount) as amount from income where deleted_at is null and year(date)=" . $data['year_select'] . "$vk group by income_cat"));

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		$hh = IncCats::get();

		foreach ($hh as $k) {
			$i[$k->id] = $k->name;

		}
		$data['expense_cats'] = $b;
		$data['income_cats'] = $i;

		$data['years'] = $y;
		$data['result'] = "";
		return view('drivers.yearly', $data);
	}

	public function monthly() {
		$d_id = Auth::user()->id;
		$bookings = Bookings::where('driver_id', $d_id)->get();
		$v_id = array('0');
		foreach ($bookings as $key) {
			if ($key->vehicle_id != null) {
				$v_id[] = $key->vehicle_id;
			}

		}

		$years = DB::select(DB::raw("select distinct year(date) as years from income  union select distinct year(date) as years from expense order by years desc"));
		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {

			$y[] = date('Y');

		}
		$data['vehicles'] = VehicleModel::whereIn('id', $v_id)->get();

		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['vehicle_select'] = null;
		$data['years'] = $y;
		$data['yearly_income'] = $this->yearly_income();
		$data['yearly_expense'] = $this->yearly_expense();
		$in = join(",", $v_id);
		$data['income'] = DB::select(DB::raw("select sum(amount) as income from income where deleted_at is null and year(date)=" . date("Y") . " and month(date)=" . date("n") . " and vehicle_id in(" . $in . ")"));
		$data['expenses'] = DB::select(DB::raw("select sum(amount) as expense from expense where deleted_at is null and year(date)=" . date("Y") . " and month(date)=" . $data['month_select'] . " and vehicle_id in(" . $in . ")"));
		$data['expense_by_cat'] = DB::select(DB::raw("select expense_type,sum(amount) as expense from expense where deleted_at is null and year(date)=" . date("Y") . " and month(date)=" . date("n") . " and vehicle_id in(" . $in . ") group by expense_type"));

		$data['income_by_cat'] = DB::select(DB::raw("select income_cat,sum(amount) as amount from income where deleted_at is null and year(date)=" . date("Y") . " and month(date)=" . date("n") . " and vehicle_id in(" . $in . ") group by income_cat"));

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		$hh = IncCats::get();

		foreach ($hh as $k) {
			$i[$k->id] = $k->name;

		}
		$data['expense_cats'] = $b;
		$data['income_cats'] = $i;
		$data['result'] = "";

		return view("drivers.monthly", $data);
	}

	public function monthly_post(Request $request) {
		$d_id = Auth::user()->id;
		$bookings = Bookings::where('driver_id', $d_id)->get();
		$v_id = array('0');
		foreach ($bookings as $key) {
			if ($key->vehicle_id != null) {
				$v_id[] = $key->vehicle_id;
			}

		}
		$years = DB::select(DB::raw("select distinct year(date) as years from income  union select distinct year(date) as years from expense order by years desc"));
		$y = array();
		$b = array();
		$i = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		if ($years == null) {
			$y = ['2017', '2016'];
		}
		$data['vehicles'] = VehicleModel::whereIn('id', $v_id)->get();
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		$data['vehicle_select'] = $request->get("vehicle_id");
		$data['yearly_income'] = $this->yearly_income();
		$data['yearly_expense'] = $this->yearly_expense();
		$vk = "";
		if ($data['vehicle_select'] != "") {
			$vk = " and vehicle_id=" . $data['vehicle_select'];
		}
		$data['income'] = DB::select(DB::raw("select sum(amount) as income from income where deleted_at is null and year(date)=" . $data['year_select'] . " and month(date)=" . $data['month_select'] . $vk));
		$data['expenses'] = DB::select(DB::raw("select sum(amount) as expense from expense where deleted_at is null and year(date)=" . $data['year_select'] . " and month(date)=" . $data['month_select'] . $vk));
		$data['expense_by_cat'] = DB::select(DB::raw("select expense_type,sum(amount) as expense from expense where deleted_at is null and year(date)=" . $data['year_select'] . " and month(date)=" . $data['month_select'] . "$vk group by expense_type"));

		$data['income_by_cat'] = DB::select(DB::raw("select income_cat,sum(amount) as amount from income where deleted_at is null and year(date)=" . $data['year_select'] . " and month(date)=" . $data['month_select'] . "$vk group by income_cat"));

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		$hh = IncCats::get();

		foreach ($hh as $k) {
			$i[$k->id] = $k->name;

		}
		$data['expense_cats'] = $b;
		$data['income_cats'] = $i;

		$data['years'] = $y;
		$data['result'] = "";
		return view("drivers.monthly", $data);
	}

	private function yearly_income() {

		$d_id = Auth::user()->id;
		$bookings = Bookings::where('driver_id', $d_id)->get();
		$v_id = array('0');
		foreach ($bookings as $key) {
			if ($key->vehicle_id != null) {
				$v_id[] = $key->vehicle_id;
			}

		}

		$in = join(",", $v_id);
		$incomes = DB::select('select monthname(date) as mnth,sum(amount) as tot from income where year(date)=? and  deleted_at is null and vehicle_id in(' . $in . ') group by month(date)', [date("Y")]);
		$months = ["January" => 0, "February" => 0, "March" => 0, "April" => 0, "May" => 0, "June" => 0, "July" => 0, "August" => 0, "September" => 0, "October" => 0, "November" => 0, "December" => 0];
		$income2 = array();

		foreach ($incomes as $income) {

			$income2[$income->mnth] = $income->tot;

		}
		$yr = array_merge($months, $income2);
		return implode(",", $yr);
	}
	private function yearly_expense() {
		$d_id = Auth::user()->id;
		$bookings = Bookings::where('driver_id', $d_id)->get();
		$v_id = array('0');
		foreach ($bookings as $key) {
			if ($key->vehicle_id != null) {
				$v_id[] = $key->vehicle_id;
			}

		}

		$in = join(",", $v_id);
		$incomes = DB::select('select monthname(date) as mnth,sum(amount) as tot from expense where year(date)=? and  deleted_at is null and vehicle_id in(' . $in . ') group by month(date)', [date("Y")]);
		$months = ["January" => 0, "February" => 0, "March" => 0, "April" => 0, "May" => 0, "June" => 0, "July" => 0, "August" => 0, "September" => 0, "October" => 0, "November" => 0, "December" => 0];
		$income2 = array();

		foreach ($incomes as $income) {

			$income2[$income->mnth] = $income->tot;

		}
		$yr = array_merge($months, $income2);
		return implode(",", $yr);

	}

}
