<?php

namespace App\Http\Controllers;
use App\Helpers\InstalledFileManager;
use App\Model\EmailContent;
use App\Model\Settings;
use App\Model\User;
use App\Model\VehicleModel;
use DB;
use File;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Schema;

class UpdateVersion extends Controller {

	public function upgrade(InstalledFileManager $fileManager) {

		if (file_exists(base_path('resources/lang/de'))) {
			File::deleteDirectory(base_path('resources/lang/de'));
		}
		if (file_exists(base_path('resources/lang/en'))) {
			File::deleteDirectory(base_path('resources/lang/en'));
		}
		if (file_exists(base_path('resources/lang/es'))) {
			File::deleteDirectory(base_path('resources/lang/es'));
		}
		if (file_exists(base_path('resources/lang/fr'))) {
			File::deleteDirectory(base_path('resources/lang/fr'));
		}
		if (file_exists(base_path('resources/lang/pt'))) {
			File::deleteDirectory(base_path('resources/lang/pt'));
		}

		Artisan::call('migrate');
		$this->add_columns();
		$this->users_meta();
		$this->store_insurance();
		$this->purchase_info();
		$this->assign_drivers();
		$fileManager->update();
		return view('laravel_web_installer.finished');
	}

	public function add_columns() {
		if (!Schema::hasColumn('bookings', 'payment')) {
			Schema::table('bookings', function ($table) {
				$table->integer('payment')->default(0);
			});
		}

		if (!Schema::hasColumn('income', 'income_id')) {
			Schema::table('income', function ($table) {
				$table->integer('income_id')->nullable();
			});
		}

		if (!Schema::hasColumn('expense', 'exp_id')) {
			Schema::table('expense', function ($table) {
				$table->integer('exp_id')->nullable();
			});
		}

		if (!Schema::hasColumn('work_orders', 'price')) {
			Schema::table('work_orders', function ($table) {
				$table->double('price', 8, 2)->default(0);
			});
		}

		if (!Schema::hasColumn('bookings_meta', 'booking_id')) {
			Schema::table('bookings_meta', function ($table) {
				$table->renameColumn('bookings_id', 'booking_id');
			});
		}

		Settings::where('name', 'language')->update(['value' => 'English-en']);

		DB::table('email_content')->truncate();
		EmailContent::create(['key' => 'insurance', 'value' => 'vehicle insurance email content']);
		EmailContent::create(['key' => 'vehicle_licence', 'value' => 'vehicle licence email content']);
		EmailContent::create(['key' => 'driving_licence', 'value' => 'driving licence email content']);
		EmailContent::create(['key' => 'registration', 'value' => 'vehicle registration email content']);
		EmailContent::create(['key' => 'service_reminder', 'value' => 'service reminder email content']);
		EmailContent::create(['key' => 'users', 'value' => '']);
		EmailContent::create(['key' => 'options', 'value' => '']);

	}

	public function users_meta() {
		$users = User::get();
		$modules = array(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10);
		foreach ($users as $u) {

			if ($u->user_type == "C" || $u->user_type == "D") {
				$u->setMeta(["language" => "English-en"]);
			}
			$u->setMeta(["language" => "English-en", "module" => serialize($modules)]);

			$u->save();

		}
	}

	public function store_insurance() {
		$ins = DB::table('insurance')->get();
		if ($ins->toArray() != null) {
			foreach ($ins as $i) {
				$v = VehicleModel::find($i->vehicle_id);
				$v->setMeta(['ins_number' => $i->ins_number,
					'ins_exp_date' => $i->ins_exp_date,
					'documents' => $i->documents]);
				$v->save();
			}
		}
	}

	public function purchase_info() {
		$acq = DB::table('acquisition')->groupBy('vehicle_id')->get(['vehicle_id']);
		if ($acq->toArray() != null) {
			foreach ($acq as $key) {
				$vehicles[] = $key->vehicle_id;
			}

			foreach ($vehicles as $vehicle) {
				$data = VehicleModel::find($vehicle);
				$purchase_info = array();
				foreach ($data->acq as $key) {

					$purchase_info[] = ['exp_name' => $key->exp_name, 'exp_amount' => $key->exp_amount];

				}

				$data->setMeta(['purchase_info' => serialize($purchase_info)]);
				$data->save();

			}
		}

	}

	public function assign_drivers() {
		$vehicles = VehicleModel::get();
		foreach ($vehicles as $v) {
			if ($v->driver_id != null) {
				$v->setMeta(['driver_id' => $v->driver_id]);
				$v->save();
			}
		}
		if (Schema::hasColumn('vehicles', 'driver_id')) {
			Schema::table('vehicles', function ($table) {
				$table->dropColumn('driver_id');
			});
		}

	}
}