<?php

namespace App\Http\Controllers;
use App\Http\Requests\InsuranceRequest;
use App\Http\Requests\VehicleRequest;
// use App\Model\AcquisitionModel;
use App\Model\DriverVehicleModel;
// use App\Model\InsuranceModel;
use App\Model\ServiceReminderModel;
use App\Model\User;
use App\Model\VehicleGroupModel;
use App\Model\VehicleModel;
use Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Input;
use Redirect;

class VehiclesController extends Controller {
	public function index() {
		$user = Auth::user();
		if ($user->group_id == null || $user->user_type == "S") {
			$index['data'] = VehicleModel::get();
		} else {
			$index['data'] = VehicleModel::where('group_id', $user->group_id)->get();}

		return view("vehicles.index", $index);
	}

	public function create() {
		$index['groups'] = VehicleGroupModel::all();
		return view("vehicles.create", $index);
	}
	public function destroy(Request $request) {
		VehicleModel::find($request->get('id'))->income()->delete();
		VehicleModel::find($request->get('id'))->expense()->delete();
		VehicleModel::find($request->get('id'))->delete();
		ServiceReminderModel::where('vehicle_id', $request->get('id'))->delete();
		return redirect()->route('vehicles.index');
	}

	public function edit($id) {
		$assigned = DriverVehicleModel::get();
		$did[] = 0;

		foreach ($assigned as $d) {
			$did[] = $d->driver_id;
		}

		$data = DriverVehicleModel::where('vehicle_id', $id)->first();
		// $except = array_diff($did, array($data->driver_id));
		if ($data != null) {
			$except = array_diff($did, array($data->driver_id));
		} else { $except = $did;}

		$drivers = User::whereUser_type("D")->whereNotIn('id', $except)->get();
		$groups = VehicleGroupModel::all();
		$vehicle = VehicleModel::where('id', $id)->get()->first();

		return view("vehicles.edit", compact('vehicle', 'groups', 'drivers'));
	}
	private function upload_file($file, $field, $id) {
		$destinationPath = './uploads'; // upload path
		$extension = $file->getClientOriginalExtension();
		$fileName1 = Str::uuid() . '.' . $extension;

		$file->move($destinationPath, $fileName1);

		$x = VehicleModel::find($id)->update([$field => $fileName1]);

	}

	private function upload_doc($file, $field, $id) {
		$destinationPath = './uploads'; // upload path
		$extension = $file->getClientOriginalExtension();
		$fileName1 = Str::uuid() . '.' . $extension;

		$file->move($destinationPath, $fileName1);
		$vehicle = VehicleModel::find($id);
		$vehicle->setMeta([$field => $fileName1]);
		$vehicle->save();

	}

	public function update(VehicleRequest $request) {
		$vehicle = $request->get('id');
		if (Input::hasFile('vehicle_image') && Input::file('vehicle_image')->isValid()) {
			$this->upload_file(Input::file('vehicle_image'), "vehicle_image", $vehicle);
		}

		$user = VehicleModel::find($request->get("id"));
		$form_data = $request->all();
		unset($form_data['vehicle_image']);
		unset($form_data['documents']);

		$user->update($form_data);

		if ($request->get("in_service")) {
			$user->in_service = 1;
		} else {
			$user->in_service = 0;
		}
		$user->int_mileage = $request->get("int_mileage");
		$user->lic_exp_date = $request->get('lic_exp_date');
		$user->reg_exp_date = $request->get('reg_exp_date');
		$user->save();

		return Redirect::route("vehicles.index");

	}

	public function store(VehicleRequest $request) {
		$user_id = $request->get('user_id');
		$vehicle = VehicleModel::create([
			'make' => $request->get("make"),
			'model' => $request->get("model"),
			'type' => $request->get("type"),
			'year' => $request->get("year"),
			'engine_type' => $request->get("engine_type"),
			'horse_power' => $request->get("horse_power"),
			'color' => $request->get("color"),
			'vin' => $request->get("vin"),
			'license_plate' => $request->get("license_plate"),
			'int_mileage' => $request->get("int_mileage"),
			'group_id' => $request->get('group_id'),
			'user_id' => $request->get('user_id'),
			'lic_exp_date' => $request->get('lic_exp_date'),
			'reg_exp_date' => $request->get('reg_exp_date'),
			'in_service' => $request->get("in_service"),
			// 'vehicle_image' => $request->get('vehicle_image'),
		])->id;
		if (Input::hasFile('vehicle_image') && Input::file('vehicle_image')->isValid()) {
			$this->upload_file(Input::file('vehicle_image'), "vehicle_image", $vehicle);
		}

		// $vehicle->insurance()->Create(
		// 	[
		// 		'ins_number' => "",
		// 	]

		// );
		$meta = VehicleModel::find($vehicle);
		$meta->setMeta([
			'ins_number' => "",
			'ins_exp_date' => "",
			'documents' => "",
		]);

		$meta->save();

		$vehicle_id = $vehicle;

		return redirect("vehicles/" . $vehicle_id . "/edit?tab=vehicle");
	}

	public function store_insurance(InsuranceRequest $request) {
		$vehicle = VehicleModel::find($request->get('vehicle_id'));
		$vehicle->setMeta([
			'ins_number' => $request->get("insurance_number"),
			'ins_exp_date' => $request->get('exp_date'),
			// 'documents' => $request->get('documents'),
		]);
		$vehicle->save();
		if (Input::hasFile('documents') && Input::file('documents')->isValid()) {
			$this->upload_doc(Input::file('documents'), 'documents', $vehicle->id);
		}

		return $vehicle;
		// return redirect('vehicles/' . $request->get('vehicle_id') . '/edit?tab=insurance');
	}

	public function view_event($id) {
		// $data['acq'] = AcquisitionModel::whereVehicle_id($id)->get();
		$data['vehicle'] = VehicleModel::where('id', $id)->get()->first();
		return view("vehicles.view_event", $data);
	}

	public function assign_driver(Request $request) {
		$vehicle = VehicleModel::find($request->get('vehicle_id'));
		$vehicle->driver_id = $request->get('driver_id');
		$vehicle->save();
		DriverVehicleModel::updateOrCreate(['vehicle_id' => $request->get('vehicle_id')], ['vehicle_id' => $request->get('vehicle_id'), 'driver_id' => $request->get('driver_id')]);
		$driver = User::find($request->get('driver_id'));
		if ($driver != null) {
			$driver->vehicle_id = $request->get('vehicle_id');
			$driver->save();}
		return redirect('vehicles/' . $request->get('vehicle_id') . '/edit?tab=driver');
	}
}
