<?php

use App\Model\ApiSettings;
use App\Model\EmailContent;
use App\Model\FareSettings;
use App\Model\Settings;
use Illuminate\Database\Seeder;

class SettingSeed extends Seeder {

	public function run() {
		$this->default_settings();
		$this->api_settings();
		$this->fare_settings();
		$this->email_settings();
	}

	private function default_settings() {
		DB::table('settings')->truncate();

		Settings::create(['label' => 'Website Name', 'name' => 'app_name', 'value' => 'Fleet Manager']);

		Settings::create(['label' => 'Business Address 1', 'name' => 'badd1', 'value' => 'Company Address 1']);
		Settings::create(['label' => 'Business Address 2', 'name' => 'badd2', 'value' => 'Company Address 2']);
		Settings::create(['label' => 'Email Address', 'name' => 'email', 'value' => 'master@admin.com']);
		Settings::create(['label' => 'City', 'name' => 'city', 'value' => 'Bhavnagar']);
		Settings::create(['label' => 'State', 'name' => 'state', 'value' => 'Gujarat']);
		Settings::create(['label' => 'Country', 'name' => 'country', 'value' => 'India']);
		Settings::create(['label' => 'Distence Format', 'name' => 'dis_format', 'value' => 'km']);
		Settings::create(['label' => 'Language', 'name' => 'language', 'value' => 'English-en']);
		Settings::create(['label' => 'Currency', 'name' => 'currency', 'value' => '₹']);
		Settings::create(['label' => 'Tax No', 'name' => 'tax_no', 'value' => 'ABCD8735XXX']);
		Settings::create(['label' => 'Invoice Text', 'name' => 'invoice_text', 'value' => 'Etsy doostang zoodles disqus groupon greplin oooj voxy zoodles, weebly ning heekya handango imeem plugg dopplr jibjab, movity jajah plickers sifteo edmodo ifttt zimbra.']);
		Settings::create(['label' => 'Small Logo', 'name' => 'icon_img', 'value' => 'logo-40.png']);
		Settings::create(['label' => 'Main Logo', 'name' => 'logo_img', 'value' => 'logo.png']);

	}

	private function api_settings() {
		DB::table('api_settings')->truncate();
		ApiSettings::create(['key_name' => 'api', 'key_value' => '1']);
		ApiSettings::create(['key_name' => 'anyone_register', 'key_value' => '0']);
		ApiSettings::create(['key_name' => 'region_availability', 'key_value' => 'region one, region two, region three']);
		ApiSettings::create(['key_name' => 'driver_review', 'key_value' => '0']);
		ApiSettings::create(['key_name' => 'booking', 'key_value' => '3']);
		ApiSettings::create(['key_name' => 'cancel', 'key_value' => '2']);

	}

	private function fare_settings() {
		DB::table('fare_settings')->truncate();
		FareSettings::create(['key_name' => 'base_fare', 'key_value' => '500']);
		FareSettings::create(['key_name' => 'base_km', 'key_value' => '10']);
		FareSettings::create(['key_name' => 'base_time', 'key_value' => '2']);
		FareSettings::create(['key_name' => 'std_fare', 'key_value' => '20']);
		FareSettings::create(['key_name' => 'weekend_base_fare', 'key_value' => '500']);
		FareSettings::create(['key_name' => 'weekend_base_km', 'key_value' => '10']);
		FareSettings::create(['key_name' => 'weekend_wait_time', 'key_value' => '2']);
		FareSettings::create(['key_name' => 'weekend_std_fare', 'key_value' => '20']);
		FareSettings::create(['key_name' => 'night_base_fare', 'key_value' => '500']);
		FareSettings::create(['key_name' => 'night_base_km', 'key_value' => '10']);
		FareSettings::create(['key_name' => 'night_wait_time', 'key_value' => '2']);
		FareSettings::create(['key_name' => 'night_std_fare', 'key_value' => '20']);
	}

	private function email_settings() {
		DB::table('email_content')->truncate();
		EmailContent::create(['key' => 'insurance', 'value' => 'vehicle insurance email content']);
		EmailContent::create(['key' => 'vehicle_licence', 'value' => 'vehicle licence email content']);
		EmailContent::create(['key' => 'driving_licence', 'value' => 'driving licence email content']);
		EmailContent::create(['key' => 'registration', 'value' => 'vehicle registration email content']);
		EmailContent::create(['key' => 'service_reminder', 'value' => 'service reminder email content']);
		EmailContent::create(['key' => 'users', 'value' => '']);
		EmailContent::create(['key' => 'options', 'value' => '']);

	}
}
