<?php

Route::get('installation', 'LaravelWebInstaller@index');
Route::post('installed', 'LaravelWebInstaller@install');
Route::get('installed', 'LaravelWebInstaller@index');
Route::get('migrate', 'LaravelWebInstaller@db_migration');
Route::get('migration', 'LaravelWebInstaller@migration');
Route::get('upgrade', 'UpdateVersion@upgrade')->middleware('canInstall');

Auth::routes();

Route::get("/clear_cache", function () {
	Artisan::call('cache:clear');
	Artisan::call('view:clear');

});

Route::get("/", 'HomeController@index')->middleware(['lang_check', 'auth']);
Route::group(['middleware' => ['lang_check', 'auth', 'officeadmin']], function () {

	Route::post('print-users-report', 'ReportsController@print_users');
	Route::post('print-customer-report', 'ReportsController@print_customer');
	Route::get('print-vendor-report', 'ReportsController@print_vendor');
	Route::post('print-driver-report', 'ReportsController@print_driver');
	Route::post('print-yearly-report', 'ReportsController@print_yearly');
	Route::post('print-fuel-report', 'ReportsController@print_fuel');
	Route::post('print-booking-report', 'ReportsController@print_booking');
	Route::post('print-deliquent-report', 'ReportsController@print_deliquent');
	Route::post('print-monthly-report', 'ReportsController@print_monthly');
	// Route::get('print-bookings', 'BookingsController@print_bookings');
	Route::get('reviews', 'ReviewRatings@index')->middleware('userpermission:10');
	Route::get('contact-us', 'ContactUs@index')->middleware('userpermission:11');
	Route::get('api-settings', 'SettingsController@api_settings')->middleware('userpermission:S');
	Route::post('api-settings', 'SettingsController@store_settings')->middleware('userpermission:S');
	Route::get('fare-settings', 'SettingsController@fare_settings')->middleware('userpermission:S');
	Route::post('fare-settings', 'SettingsController@store_fareSettings')->middleware('userpermission:S');
	Route::resource('service-reminder', 'ServiceReminderController')->middleware('userpermission:9');
	Route::resource('service-item', 'ServiceItemsController')->middleware('userpermission:9');
	// Route::get('/parts-used', 'CompletedServiceController@parts_used');
	// Route::resource('/technician', 'TechnicianController');
	Route::resource('/vehicle_group', 'VehicleGroupController')->middleware('userpermission:1');
	Route::post('/income_records', 'Income@income_records')->middleware('userpermission:2');
	Route::post('/expense_records', 'ExpenseController@expense_records')->middleware('userpermission:2');
	Route::post('/store_insurance', 'VehiclesController@store_insurance');
	Route::get('vehicle/event/{id}', 'VehiclesController@view_event')->middleware('userpermission:1');
	Route::post('assignDriver', 'VehiclesController@assign_driver');
	// Route::resource('/notes', 'NotesController');
	Route::resource('/work_order', 'WorkOrdersController')->middleware('userpermission:7');
	// Route::get('/completed-services', 'WorkOrdersController@completed_service');
	Route::resource('/vendor', 'VendorController')->middleware('userpermission:6');
	Route::resource('/fuel', 'FuelController')->middleware('userpermission:5');
	Route::resource('/drivers', 'DriversController')->middleware('userpermission:0');
	// Route::resource('/parts', 'PartsController');
	Route::resource('/vehicles', 'VehiclesController')->middleware('userpermission:1');
	Route::resource('/bookings', 'BookingsController')->middleware('userpermission:3');
	Route::post('/prev-address', 'BookingsController@prev_address');
	Route::get('print/{id}', 'BookingsController@print')->middleware('userpermission:3');
	Route::resource('/acquisition', 'AcquisitionController');
	Route::resource('/income', 'Income')->middleware('userpermission:2');
	// Route::resource('/stock', 'StockController');
	Route::resource('/settings', 'SettingsController')->middleware('userpermission:S');
	Route::resource('/customers', 'CustomersController')->middleware('userpermission:0');
	Route::resource('/expense', 'ExpenseController')->middleware('userpermission:2');
	Route::resource('/expensecategories', 'ExpenseCategories')->middleware('userpermission:S');
	Route::resource('/incomecategories', 'IncomeCategories')->middleware('userpermission:S');
	Route::resource('/searchdrivers', 'SearchdriversController');
	Route::resource('/searchvehicles', 'SearchvehiclesController');

	Route::get('/bookings/complete/{id}', 'BookingsController@complete')->middleware('userpermission:3');
	Route::get('/bookings/receipt/{id}', 'BookingsController@receipt')->middleware('userpermission:3');
	Route::get('/bookings/payment/{id}', 'BookingsController@payment')->middleware('userpermission:3');
	Route::get("/reports/monthly", "ReportsController@monthly")->name("reports.monthly")->middleware('userpermission:4');
	Route::get("/reports/vendors", "ReportsController@vendors")->name("reports.vendors")->middleware('userpermission:4');
	Route::post("/reports/vendors", "ReportsController@vendors_post")->name("reports.vendors")->middleware('userpermission:4');
	Route::get("reports/drivers", "ReportsController@drivers")->name("reports.drivers")->middleware('userpermission:4');
	Route::post("reports/drivers", "ReportsController@drivers_post")->name("reports.drivers")->middleware('userpermission:4');
	Route::get("reports/customers", "ReportsController@customers")->name("reports.customers")->middleware('userpermission:4');
	Route::post("reports/customers", "ReportsController@customers_post")->name("reports.customers")->middleware('userpermission:4');
	// Route::get("/reports/parts", "ReportsController@parts")->name("reports.parts");
	Route::get("/reports/booking", "ReportsController@booking")->name("reports.booking")->middleware('userpermission:4');
	Route::get("/reports/delinquent", "ReportsController@delinquent")->name("reports.delinquent")->middleware('userpermission:4');
	Route::get("/reports/users", "ReportsController@users")->name("reports.users")->middleware('userpermission:4');
	Route::post("/reports/users", "ReportsController@users_post")->name("reports.users")->middleware('userpermission:4');
	Route::get('/calendar', 'BookingsController@calendar');
	Route::get('/calendar/event/{id}', 'BookingsController@calendar_event');
	Route::get("/drivers/enable/{id}", 'DriversController@enable');
	Route::get("/drivers/disable/{id}", 'DriversController@disable');
	Route::get("/reports/vehicle", "ReportsController@vehicle")->name("reports.vehicle");
	// Route::get('/stock/add/{id}', 'StockController@add');

	Route::post("/reports/booking", "ReportsController@booking_post")->name("reports.booking")->middleware('userpermission:4');
	Route::post("/reports/fuel", "ReportsController@fuel_post")->name("reports.fuel")->middleware('userpermission:4');
	Route::get("/reports/fuel", "ReportsController@fuel")->name("reports.fuel")->middleware('userpermission:4');
	Route::get("/reports/yearly", "ReportsController@yearly")->name("reports.yearly")->middleware('userpermission:4');
	Route::post("/reports/yearly", "ReportsController@yearly_post")->name("reports.yearly")->middleware('userpermission:4');

	Route::post('/customer/ajax_save', 'CustomersController@ajax_store')->name('customers.ajax_store');
	Route::get("/bookings_calendar", 'BookingsController@calendar_view')->name("bookings.calendar")->middleware('userpermission:3');
	Route::get('/calendar/event/calendar/{id}', 'BookingsController@calendar_event');
	Route::get('/calendar/event/service/{id}', 'BookingsController@service_view');
	Route::get('/calendar', 'BookingsController@calendar');
	Route::post('/drivers/add', 'DriversController@add');
	Route::post('/searchvehicles/search', 'SearchvehiclesController@search');
	Route::post('/searchdrivers/search', 'SearchdriversController@search');
	Route::post('/get_driver', 'BookingsController@get_driver');
	Route::post('/get_vehicle', 'BookingsController@get_vehicle');
	Route::post('/bookings/complete', 'BookingsController@complete_post')->name("bookings.complete");
	Route::get('/bookings/complete', 'BookingsController@complete_post')->name("bookings.complete")->middleware('userpermission:3');

	Route::post("/reports/monthly", "ReportsController@monthly_post")->name("reports.monthly")->middleware('userpermission:4');
	Route::post("/reports/booking", "ReportsController@booking_post")->name("reports.booking")->middleware('userpermission:4');
	// Route::post("/reports/parts", "ReportsController@parts_post")->name("reports.parts");
	Route::post("/reports/delinquent", "ReportsController@delinquent_post")->name("reports.delinquent")->middleware('userpermission:4');
	Route::get("/send-email", "SettingsController@send_email")->middleware('userpermission:S');
	Route::post("/email-settings", "SettingsController@email_settings")->middleware('userpermission:S');
	Route::get("/set-email", "SettingsController@set_email")->middleware('userpermission:S');
	Route::post("/set-content/{type}", "SettingsController@set_content")->middleware('userpermission:S');
});

Route::group(['middleware' => ['lang_check', 'auth']], function () {
	Route::get('changepassword/{id}', 'UtilityController@change');
	Route::post('changepassword/{id}', 'UtilityController@change_post');
	Route::get('/change-details/{id}', 'UtilityController@changepass')->name("changepass");
	Route::post('/change-details/{id}', 'UtilityController@changepassword')->name("changepass");
	Route::post('/change_password', 'UtilityController@password_change');
	Route::get('/vehicle_notification/{type}', 'NotificationController@vehicle_notification');
	Route::resource('/notes', 'NotesController')->middleware('userpermission:8');
	Route::get('driver_notification/{type}', 'NotificationController@driver_notification');
	Route::get('/reminder/{type}', 'NotificationController@service_reminder');
	Route::get('/my_bookings', 'DriversController@my_bookings')->name('my_bookings');

	// driver reports
	Route::get("/driver-reports/yearly", "DriversController@yearly")->name("dreports.yearly");;
	Route::post("/driver-reports/yearly", "DriversController@yearly_post")->name("dreports.yearly");
	Route::get("/driver-reports/monthly", "DriversController@monthly")->name("dreports.monthly");
	Route::post("/driver-reports/monthly", "DriversController@monthly_post")->name("dreports.monthly");
	Route::get('/addresses', 'AddressController@index');

	Route::resource('/cancel-reason', 'ReasonController')->middleware('userpermission:3');
});
Route::group(['middleware' => ['lang_check', 'auth', 'superadmin']], function () {
	Route::resource('/users', 'UsersController')->middleware('userpermission:0');
});